@@ -20,7 +20,6 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <syslog.h>
 #include <unistd.h>
 #include <dirent.h>
 #include <string.h>
@@ -39,6 +38,7 @@
 #include "greeter_item_pam.h"
 #include "greeter_configuration.h"
 #include "greeter_events.h"
+#include "greeter_parser.h"
 
 #define LAST_SESSION "Last"
 #define LAST_LANGUAGE "Last"
@@ -123,7 +123,8 @@ greeter_session_lookup (const char *saved_session)
 	  secondmsg = g_strdup_printf (_("Your preferred session type %s is not "
 	                                 "installed on this computer."),
 	                               gdm_session_name (default_session));
-	  save_session = gdm_common_query (firstmsg, secondmsg, _("Make _Default"), _("Just _Log In"), TRUE);
+	  save_session = gdm_wm_query_dialog (firstmsg, secondmsg,
+		_("Make _Default"), _("Just _Log In"), TRUE);
 	  g_free (firstmsg);
 	  g_free (secondmsg);
 	}
@@ -155,7 +156,8 @@ greeter_session_lookup (const char *saved_session)
 	                                     "setting is %s."),
 	                                   gdm_session_name (session),
 	                                   gdm_session_name (saved_session));
-	      save_session = gdm_common_query (firstmsg, secondmsg, _("Make _Default"), _("Just For _This Session"), TRUE);
+	      save_session = gdm_wm_query_dialog (firstmsg, secondmsg,
+			_("Make _Default"), _("Just For _This Session"), TRUE);
 	    }
 	  else if (strcmp (session, default_session) != 0 &&
 		   strcmp (session, saved_session) != 0 &&
@@ -166,7 +168,7 @@ greeter_session_lookup (const char *saved_session)
 	       * irrelevant, we are in "switchdesk mode" and the relevant
 	       * thing is the saved session in .Xclients
 	       */
-	      if (access ("/usr/bin/switchdesk", F_OK) == 0)
+	      if (g_access ("/usr/bin/switchdesk", F_OK) == 0)
 	        {
 	          firstmsg = g_strdup_printf (_("You have chosen %s for this "
 	                                        "session"),
@@ -177,7 +179,7 @@ greeter_session_lookup (const char *saved_session)
 	                                         "(System->Desktop Switching Tool from "
 	                                         "the panel menu)."),
 	                                       gdm_session_name (session));			 
-		  gdm_common_message (firstmsg, secondmsg);
+		  gdm_wm_message_dialog (firstmsg, secondmsg);
 		}
 	      save_session = GTK_RESPONSE_NO;
 	    }
@@ -185,7 +187,7 @@ greeter_session_lookup (const char *saved_session)
 	  g_free (secondmsg);
 	}
     }
-  
+
   return session;
 }
 
@@ -295,7 +297,7 @@ greeter_session_init (void)
 		label = g_strdup_printf ("_%d. %s", num, session->name);
 	else
 		label = g_strdup (session->name);
-	num ++;
+	num++;
  
 	radio = gtk_radio_button_new_with_mnemonic (session_group, label);
 	g_free (label);
@@ -339,10 +341,16 @@ greeter_session_init (void)
    }
 }
 
+/* 
+ * The button with this handler appears in the F10 menu, so it
+ * cannot depend on callback data being passed in.
+ */
 static void
 greeter_session_handler (GreeterItemInfo *info,
 			 gpointer         user_data)
 {
+  GreeterItemInfo *entry_info = greeter_lookup_id ("user-pw-entry");
+  GtkWidget *entry = GNOME_CANVAS_WIDGET (entry_info->item)->widget;
   GSList *tmp;
   int ret;
   
@@ -394,6 +402,7 @@ greeter_session_handler (GreeterItemInfo *info,
 	  tmp = tmp->next;
 	}
     }
+  gtk_widget_grab_focus (entry);
 }
 
 void
